ContainerMatcher extension
Matchers for the properties of Container provided via Diagnosticable.debugFillProperties
Methods
-
hasAlignment(
AlignmentGeometry? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that alignment of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasAlignmentWhere(
MatchProp< AlignmentGeometry> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that alignment of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasBackground(
Decoration? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that background of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasBackgroundWhere(
MatchProp< Decoration> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that background of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasClipBehavior(
Clip? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that clipBehavior of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasClipBehaviorWhere(
MatchProp< Clip> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that clipBehavior of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasConstraints(
BoxConstraints? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that constraints of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasConstraintsWhere(
MatchProp< BoxConstraints> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that constraints of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasForeground(
Decoration? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that foreground of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasForegroundWhere(
MatchProp< Decoration> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that foreground of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasMargin(
EdgeInsetsGeometry? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that margin of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasMarginWhere(
MatchProp< EdgeInsetsGeometry> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that margin of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasPadding(
EdgeInsetsGeometry? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that padding of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasPaddingWhere(
MatchProp< EdgeInsetsGeometry> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that padding of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch. -
hasTransform(
Matrix4? value) → WidgetMatcher< Container> -
Available on WidgetMatcher<
Expects that transform of Container equals (==)Container> , provided by the ContainerMatcher extensionvalue. -
hasTransformWhere(
MatchProp< Matrix4> match) → WidgetMatcher<Container> -
Available on WidgetMatcher<
Expects that transform of Container matches the condition inContainer> , provided by the ContainerMatcher extensionmatch.